@@ -214,7 +214,7 @@ gda_data_model_get_type (void)
  * gda_data_model_changed
  * @model: a #GdaDataModel object.
  *
- * Notify listeners of the given data model object of changes
+ * Notifies listeners of the given data model object of changes
  * in the underlying data. Listeners usually will connect
  * themselves to the "changed" signal in the #GdaDataModel
  * class, thus being notified of any new data being appended
@@ -234,7 +234,10 @@ gda_data_model_changed (GdaDataModel *model)
 
 /**
  * gda_data_model_row_inserted
- * model: a #GdaDataModel object.
+ * @model: a #GdaDataModel object.
+ * @row: row number.
+ *
+ * Emits the 'row_inserted' and 'changed' signals on @model.
  */
 void
 gda_data_model_row_inserted (GdaDataModel *model, gint row)
@@ -245,12 +248,17 @@ gda_data_model_row_inserted (GdaDataModel *model, gint row)
 		g_signal_emit (G_OBJECT (model),
 			       gda_data_model_signals[ROW_INSERTED],
 			       0, row);
+
+		gda_data_model_changed (model);
 	}
 }
 
 /**
  * gda_data_model_row_updated
- * model: a #GdaDataModel object.
+ * @model: a #GdaDataModel object.
+ * @row: row number.
+ *
+ * Emits the 'row_updated' and 'changed' signals on @model.
  */
 void
 gda_data_model_row_updated (GdaDataModel *model, gint row)
@@ -261,12 +269,17 @@ gda_data_model_row_updated (GdaDataModel *model, gint row)
 		g_signal_emit (G_OBJECT (model),
 			       gda_data_model_signals[ROW_UPDATED],
 			       0, row);
+
+		gda_data_model_changed (model);
 	}
 }
 
 /**
  * gda_data_model_row_removed
- * model: a #GdaDataModel object.
+ * @model: a #GdaDataModel object.
+ * @row: row number.
+ *
+ * Emits the 'row_removed' and 'changed' signal on @model.
  */
 void
 gda_data_model_row_removed (GdaDataModel *model, gint row)
@@ -277,6 +290,8 @@ gda_data_model_row_removed (GdaDataModel *model, gint row)
 		g_signal_emit (G_OBJECT (model),
 			       gda_data_model_signals[ROW_REMOVED],
 			       0, row);
+
+		gda_data_model_changed (model);
 	}
 }
 
@@ -284,7 +299,7 @@ gda_data_model_row_removed (GdaDataModel *model, gint row)
  * gda_data_model_freeze
  * @model: a #GdaDataModel object.
  *
- * Disable notifications of changes on the given data model. To
+ * Disables notifications of changes on the given data model. To
  * re-enable notifications again, you should call the
  * #gda_data_model_thaw function.
  */
@@ -299,7 +314,7 @@ gda_data_model_freeze (GdaDataModel *model)
  * gda_data_model_thaw
  * @model: a #GdaDataModel object.
  *
- * Re-enable notifications of changes on the given data model.
+ * Re-enables notifications of changes on the given data model.
  */
 void
 gda_data_model_thaw (GdaDataModel *model)
@@ -312,7 +327,7 @@ gda_data_model_thaw (GdaDataModel *model)
  * gda_data_model_get_n_rows
  * @model: a #GdaDataModel object.
  *
- * Return the number of rows in the given data model.
+ * Returns: the number of rows in the given data model.
  */
 gint
 gda_data_model_get_n_rows (GdaDataModel *model)
@@ -327,7 +342,7 @@ gda_data_model_get_n_rows (GdaDataModel *model)
  * gda_data_model_get_n_columns
  * @model: a #GdaDataModel object.
  *
- * Return the number of columns in the given data model.
+ * Returns: the number of columns in the given data model.
  */
 gint
 gda_data_model_get_n_columns (GdaDataModel *model)
@@ -343,7 +358,7 @@ gda_data_model_get_n_columns (GdaDataModel *model)
  * @model: a #GdaDataModel object.
  * @col: column number.
  *
- * Query the underlying data model implementation for a description
+ * Queries the underlying data model implementation for a description
  * of a given column. That description is returned in the form of
  * a #GdaFieldAttributes structure, which contains all the information
  * about the given column in the data model.
@@ -385,7 +400,7 @@ gda_data_model_describe_column (GdaDataModel *model, gint col)
  * @model: a #GdaDataModel object.
  * @col: column number.
  *
- * Return the title for the given column in a data model object.
+ * Returns: the title for the given column in a data model object.
  */
 const gchar *
 gda_data_model_get_column_title (GdaDataModel *model, gint col)
@@ -425,6 +440,8 @@ gda_data_model_get_column_title (GdaDataModel *model, gint col)
  * @model: a #GdaDataModel object.
  * @col: column number
  * @title: title for the given column.
+ *
+ * Sets the @title of the given @col in @model.
  */
 void
 gda_data_model_set_column_title (GdaDataModel *model, gint col, const gchar *title)
@@ -455,7 +472,7 @@ gda_data_model_set_column_title (GdaDataModel *model, gint col, const gchar *tit
  * @model: a #GdaDataModel object.
  * @title: column title.
  *
- * Get the position of a column on the data model, based on
+ * Gets the position of a column on the data model, based on
  * the column's title.
  *
  * Returns: the position of the column in the data model, or -1
@@ -488,7 +505,7 @@ gda_data_model_get_column_position (GdaDataModel *model, const gchar *title)
  * @model: a #GdaDataModel object.
  * @row: row number.
  *
- * Retrieve a given row from a data model.
+ * Retrieves a given row from a data model.
  *
  * Returns: a #GdaRow object.
  */
@@ -507,13 +524,13 @@ gda_data_model_get_row (GdaDataModel *model, gint row)
  * @col: column number.
  * @row: row number.
  *
- * Retrieve the data stored in the given position (identified by
+ * Retrieves the data stored in the given position (identified by
  * the @col and @row parameters) on a data model.
  *
  * This is the main function for accessing data in a model.
  *
  * Returns: a #GdaValue containing the value stored in the given
- * position, or NULL on error (out-of-bound position, etc).
+ * position, or %NULL on error (out-of-bound position, etc).
  */
 const GdaValue *
 gda_data_model_get_value_at (GdaDataModel *model, gint col, gint row)
@@ -528,9 +545,9 @@ gda_data_model_get_value_at (GdaDataModel *model, gint col, gint row)
  * gda_data_model_is_editable
  * @model: a #GdaDataModel object.
  *
- * Check whether the given data model can be edited or not.
+ * Checks whether the given data model can be edited or not.
  *
- * Returns: TRUE if it can be edited, FALSE if not.
+ * Returns: %TRUE if it can be edited, %FALSE if not.
  */
 gboolean
 gda_data_model_is_editable (GdaDataModel *model)
@@ -546,17 +563,21 @@ gda_data_model_is_editable (GdaDataModel *model)
  * @model: a #GdaDataModel object.
  * @values: the row to add.
  *
- * Append a row to the given data model.
+ * Appends a row to the given data model.
  *
- * Returns: the unique ID of the added row.
+ * Returns: the added row.
  */
 const GdaRow *
 gda_data_model_append_row (GdaDataModel *model, const GList *values)
 {
+	const GdaRow *row;
+
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), NULL);
 	g_return_val_if_fail (CLASS (model)->append_row != NULL, NULL);
 
-	return CLASS (model)->append_row (model, values);
+	row = CLASS (model)->append_row (model, values);
+	gda_data_model_row_inserted (model, gda_row_get_number ((GdaRow *) row));
+	return row;
 }
 
 /**
@@ -564,19 +585,26 @@ gda_data_model_append_row (GdaDataModel *model, const GList *values)
  * @model: a #GdaDataModel object.
  * @row: the #GdaRow to be removed.
  *
- * Remove a row from the data model. This results in the underlying
+ * Removes a row from the data model. This results in the underlying
  * database row being removed in the database.
  *
- * Returns: TRUE if successful, FALSE otherwise.
+ * Returns: %TRUE if successful, %FALSE otherwise.
  */
 gboolean
 gda_data_model_remove_row (GdaDataModel *model, const GdaRow *row)
 {
+	gboolean result;
+
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), FALSE);
 	g_return_val_if_fail (row != NULL, FALSE);
 	g_return_val_if_fail (CLASS (model)->remove_row != NULL, FALSE);
 
-	return CLASS (model)->remove_row (model, row);
+	result = CLASS (model)->remove_row (model, row);
+	if (result) {
+		gda_data_model_row_removed (model, gda_row_get_number ((GdaRow *) row));
+	}
+
+	return result;
 }
 
 /**
@@ -584,19 +612,25 @@ gda_data_model_remove_row (GdaDataModel *model, const GdaRow *row)
  * @model: a #GdaDataModel object.
  * @row: the #GdaRow to be updated.
  *
- * Update a row data model. This results in the underlying
+ * Updates a row data model. This results in the underlying
  * database row's values being changed.
  *
- * Returns: TRUE if successful, FALSE otherwise.
+ * Returns: %TRUE if successful, %FALSE otherwise.
  */
 gboolean
 gda_data_model_update_row (GdaDataModel *model, const GdaRow *row)
 {
+	gboolean result;
+
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), FALSE);
 	g_return_val_if_fail (row != NULL, FALSE);
 	g_return_val_if_fail (CLASS (model)->update_row != NULL, FALSE);
 
-	return CLASS (model)->update_row (model, row);
+	result = CLASS (model)->update_row (model, row);
+	if (result) {
+		gda_data_model_row_updated (model, gda_row_get_number ((GdaRow *) row));
+	}
+	return result;
 }
 
 /**
@@ -605,7 +639,7 @@ gda_data_model_update_row (GdaDataModel *model, const GdaRow *row)
  * @func: callback function.
  * @user_data: context data for the callback function.
  *
- * Call the specified callback function for each row in the data model.
+ * Calls the specified callback function for each row in the data model.
  * This will just traverse all rows, and call the given callback
  * function for each of them.
  *
@@ -615,8 +649,8 @@ gda_data_model_update_row (GdaDataModel *model, const GdaRow *row)
  *
  * where "row" would be the row being read, and "user_data" the parameter
  * specified in @user_data in the call to gda_data_model_foreach.
- * This callback function can return FALSE to stop the processing. If it
- * returns TRUE, processing will continue until no rows remain.
+ * This callback function can return %FALSE to stop the processing. If it
+ * returns %TRUE, processing will continue until no rows remain.
  */
 void
 gda_data_model_foreach (GdaDataModel *model,
@@ -653,13 +687,13 @@ gda_data_model_foreach (GdaDataModel *model,
  * gda_data_model_is_editing
  * @model: a #GdaDataModel object.
  *
- * Check whether this data model is in editing mode or not. Editing
- * mode is set to TRUE when @gda_data_model_begin_edit has been
- * called successfully, and is not set back to FALSE until either
+ * Checks whether this data model is in editing mode or not. Editing
+ * mode is set to %TRUE when @gda_data_model_begin_edit has been
+ * called successfully, and is not set back to %FALSE until either
  * @gda_data_model_cancel_edit or @gda_data_model_end_edit have
  * been called.
  *
- * Returns: TRUE if editing mode, FALSE otherwise.
+ * Returns: %TRUE if editing mode, %FALSE otherwise.
  */
 gboolean
 gda_data_model_is_editing (GdaDataModel *model)
@@ -672,10 +706,10 @@ gda_data_model_is_editing (GdaDataModel *model)
  * gda_data_model_begin_edit
  * @model: a #GdaDataModel object.
  *
- * Start edition of this data model. This function should be the
+ * Starts edition of this data model. This function should be the
  * first called when modifying the data model.
  *
- * Returns: TRUE on success, FALSE if there was an error.
+ * Returns: %TRUE on success, %FALSE if there was an error.
  */
 gboolean
 gda_data_model_begin_edit (GdaDataModel *model)
@@ -701,7 +735,7 @@ gda_data_model_begin_edit (GdaDataModel *model)
  * Cancels edition of this data model. This means that all changes
  * will be discarded, and the old data put back in the model.
  *
- * Returns: TRUE on success, FALSE if there was an error.
+ * Returns: %TRUE on success, %FALSE if there was an error.
  */
 gboolean
 gda_data_model_cancel_edit (GdaDataModel *model)
@@ -722,7 +756,7 @@ gda_data_model_cancel_edit (GdaDataModel *model)
  * Approves all modifications and send them to the underlying
  * data source/store.
  *
- * Returns: TRUE on success, FALSE if there was an error.
+ * Returns: %TRUE on success, %FALSE if there was an error.
  */
 gboolean
 gda_data_model_end_edit (GdaDataModel *model)
@@ -779,7 +813,7 @@ export_to_separated (GdaDataModel *model, gchar sep)
  * gda_data_model_to_comma_separated
  * @model: a #GdaDataModel object.
  *
- * Convert the given model into a comma-separated series of rows.
+ * Converts the given model into a comma-separated series of rows.
  *
  * Returns: the representation of the model. You should free this
  * string when you no longer need it.
@@ -792,6 +826,12 @@ gda_data_model_to_comma_separated (GdaDataModel *model)
 
 /**
  * gda_data_model_to_tab_separated
+ * @model: a #GdaDataModel object.
+ *
+ * Converts the given model into a tab-separated series of rows.
+ *
+ * Returns: the representation of the model. You should free this
+ * string when you no longer need it.
  */
 gchar *
 gda_data_model_to_tab_separated (GdaDataModel *model)
@@ -801,21 +841,32 @@ gda_data_model_to_tab_separated (GdaDataModel *model)
 
 /**
  * gda_data_model_to_xml
+ * @model: a #GdaDataModel object.
+ * @standalone: whether ... 
+ *
+ * Converts the given model into a XML representation.
+ *
+ * Returns: the representation of the model. You should free this
+ * string when you no longer need it.
  */
 gchar *
 gda_data_model_to_xml (GdaDataModel *model, gboolean standalone)
 {
-	xmlDocPtr xml_doc;
-	xmlNodePtr xml_root, xml_node, xml_tables;
-	gchar *xml = NULL;
 	xmlChar *xml_contents;
+	xmlNodePtr xml_node;
+	gchar *xml;
 	gint size;
 
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), NULL);
 
 	xml_node = gda_data_model_to_xml_node (model, "exported_model");
+
 	if (standalone) {
+		xmlDocPtr xml_doc;
+		xmlNodePtr xml_root, xml_tables;
+	
 		xml_doc = xmlNewDoc ("1.0");
+		
 		xml_root = xmlNewDocNode (xml_doc, NULL, "database", NULL);
 		xmlDocSetRootElement (xml_doc, xml_root);
 
@@ -824,7 +875,15 @@ gda_data_model_to_xml (GdaDataModel *model, gboolean standalone)
 
 		xmlDocDumpMemory (xml_doc, &xml_contents, &size);
 		xmlFreeDoc (xml_doc);
-
+		
+		xml = g_strdup (xml_contents);
+		xmlFree (xml_contents);
+	}
+	else {
+		xmlBufferPtr xml_buf = xmlBufferCreate ();
+		xmlNodeDump (xml_buf, NULL, xml_node, 0, 0); 
+		xml_contents = (xmlChar *) xmlBufferContent (xml_buf);
+		xmlBufferFree (xml_buf);
 		xml = g_strdup (xml_contents);
 	}
 
@@ -848,10 +907,10 @@ xml_set_int (xmlNodePtr node, const gchar *name, gint value)
 
 /**
  * gda_data_model_to_xml_node
- * @model: A #GdaDataModel object.
- * @name: Name to use for the XML resulting table.
+ * @model: a #GdaDataModel object.
+ * @name: name to use for the XML resulting table.
  *
- * Convert a #GdaDataModel into a xmlNodePtr (as used in libxml).
+ * Converts a #GdaDataModel into a xmlNodePtr (as used in libxml).
  *
  * Returns: a xmlNodePtr representing the whole data model.
  */
@@ -993,9 +1052,9 @@ add_xml_row (GdaDataModel *model, xmlNodePtr xml_row)
  * @model: a #GdaDataModel.
  * @node: a XML node representing a <data> XML node.
  *
- * Add the data from a XML node to the given data model.
+ * Adds the data from a XML node to the given data model.
  *
- * Returns: TRUE if successful, FALSE otherwise.
+ * Returns: %TRUE if successful, %FALSE otherwise.
  */
 gboolean
 gda_data_model_add_data_from_xml_node (GdaDataModel *model, xmlNodePtr node)
@@ -1022,7 +1081,7 @@ gda_data_model_add_data_from_xml_node (GdaDataModel *model, xmlNodePtr node)
  * gda_data_model_get_command_text
  * @model: a #GdaDataModel.
  *
- * Get the text of command that generated this data model.
+ * Gets the text of command that generated this data model.
  *
  * Returns: a string with the command issued.
  */
@@ -1037,6 +1096,8 @@ gda_data_model_get_command_text (GdaDataModel *model)
  * gda_data_model_set_command_text
  * @model: a #GdaDataModel.
  * @txt: the command text.
+ *
+ * Sets the command text of the given @model.
  */
 void
 gda_data_model_set_command_text (GdaDataModel *model, const gchar *txt)
@@ -1053,7 +1114,7 @@ gda_data_model_set_command_text (GdaDataModel *model, const gchar *txt)
  * gda_data_model_get_command_type
  * @model: a #GdaDataModel.
  *
- * Get the type of command that generated this data model.
+ * Gets the type of command that generated this data model.
  *
  * Returns: a #GdaCommandType.
  */
@@ -1068,6 +1129,8 @@ gda_data_model_get_command_type (GdaDataModel *model)
  * gda_data_model_set_command_type
  * @model: a #GdaDataModel.
  * @type: the type of the command (one of #GdaCommandType)
+ *
+ * Sets the type of command that generated this data model.
  */
 void
 gda_data_model_set_command_type (GdaDataModel *model, GdaCommandType type)
